==> activity-center-api-0.8.5.0.1-lqs1-20180131.085119-1-sources.jar: cn/com/duiba/tuia/activity/center/api/dto/GameConfigDto.java <==
package cn.com.duiba.tuia.activity.center.api.dto;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by Administrator on 2018/1/23.
 */
public class GameConfigDto implements Serializable {

    private static final long serialVersionUID = -529728345973476485L;
    /**
     *
     */
    private Long id;

    /**
     * 游戏名称
     */
    private String title;

    /**
     * 1:捕鱼类;2:拼图类;3:押注类
     *
     * @see cn.com.duiba.tuia.activity.center.api.constant.GameType
     */
    private Integer gameType;

    /**
     * 1:普通游戏;2:独立游戏
     */
    private Integer dockType;

    /**
     * 返奖率
     */
    private String returnRate;

    /**
     * 扩展字段
     */
    private ExtInfo extInfo;

    /**
     * 是否删除（1：删除 0：正常）
     */
    private Integer isDeleted;

    /**
     * 创建时间
     */
    private Date gmtCreate;

    /**
     * 修改时间
     */
    private Date gmtModified;

    private String ruleConfigDto;

    public String getRuleConfigDto() {
        return ruleConfigDto;
    }

    public void setRuleConfigDto(String ruleConfigDto) {
        this.ruleConfigDto = ruleConfigDto;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public Integer getGameType() {
        return gameType;
    }

    public void setGameType(Integer gameType) {
        this.gameType = gameType;
    }

    public Integer getDockType() {
        return dockType;
    }

    public void setDockType(Integer dockType) {
        this.dockType = dockType;
    }

    public String getReturnRate() {
        return returnRate;
    }

    public void setReturnRate(String returnRate) {
        this.returnRate = returnRate;
    }

    public Integer getIsDeleted() {
        return isDeleted;
    }

    public void setIsDeleted(Integer isDeleted) {
        this.isDeleted = isDeleted;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public ExtInfo getExtInfo() {
        return extInfo;
    }

    public void setExtInfo(ExtInfo extInfo) {
        this.extInfo = extInfo;
    }

}

==> activity-center-api-0.8.9.3-lqs20-20180419.021303-1-sources.jar: cn/com/duiba/tuia/activity/center/api/dto/GameConfigDto.java <==
package cn.com.duiba.tuia.activity.center.api.dto;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by Administrator on 2018/1/23.
 */
public class GameConfigDto implements Serializable {

    private static final long serialVersionUID = -529728345973476485L;
    /**
     *
     */
    private Long id;

    /**
     * 游戏名称
     */
    private String title;

    /**
     * 1:捕鱼类;2:拼图类;3:押注类
     *
     * @see cn.com.duiba.tuia.activity.center.api.constant.GameType
     */
    private Integer gameType;

    /**
     * 1:普通游戏;2:独立游戏
     */
    private Integer dockType;

    /**
     * 返奖率
     */
    private String returnRate;

    /**
     * 扩展字段
     */
    private ExtInfo extInfo;

    /**
     * 是否删除（1：删除 0：正常）
     */
    private Integer isDeleted;

    /**
     * 创建时间
     */
    private Date gmtCreate;

    /**
     * 修改时间
     */
    private Date gmtModified;

    private String ruleConfigDto;

    /**
     * 游戏开启关闭状态
     */
    private Integer enableStatus;

    public String getRuleConfigDto() {
        return ruleConfigDto;
    }

    public void setRuleConfigDto(String ruleConfigDto) {
        this.ruleConfigDto = ruleConfigDto;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public Integer getGameType() {
        return gameType;
    }

    public void setGameType(Integer gameType) {
        this.gameType = gameType;
    }

    public Integer getDockType() {
        return dockType;
    }

    public void setDockType(Integer dockType) {
        this.dockType = dockType;
    }

    public String getReturnRate() {
        return returnRate;
    }

    public void setReturnRate(String returnRate) {
        this.returnRate = returnRate;
    }

    public Integer getIsDeleted() {
        return isDeleted;
    }

    public void setIsDeleted(Integer isDeleted) {
        this.isDeleted = isDeleted;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public ExtInfo getExtInfo() {
        return extInfo;
    }

    public void setExtInfo(ExtInfo extInfo) {
        this.extInfo = extInfo;
    }

    public Integer getEnableStatus() {
        return enableStatus;
    }

    public void setEnableStatus(Integer enableStatus) {
        this.enableStatus = enableStatus;
    }
}
